Font Awesome and Markdown, together!
------------------------------------

For when words aren't enough.
-----------------------------

A Markdown extension that looks for things like ``:icon-coffee:`` and replaces
them with the Font Awesome icon markup, users of GitHub's emoji are likely to
find this somewhat familiar.

Add a ``FontAwesomeExtension`` instance to your Markdown call and watch the
magic unfold::

    >>> from markdown import Markdown
    >>> from fontawesome_markdown import FontAwesomeExtension

    >>> markdown = Markdown(extensions=[FontAwesomeExtension()]
    >>> markdown.convert('i ♥ :icon-coffee:')
    <p>i ♥ <i class="icon icon-coffee"></i></p>

Don't forget to make the Font Awesome assets available in your DOM!
